==> kubernetes-model-admissionregistration-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/admission/v1beta1/AdmissionReviewBuilder.java <==
package io.fabric8.kubernetes.api.model.admission.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class AdmissionReviewBuilder extends io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluentImpl<io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewBuilder> {

    io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent;
    Boolean validationEnabled;

    public AdmissionReviewBuilder() {
        this(true);
    }

    public AdmissionReviewBuilder(Boolean validationEnabled) {
        this(new AdmissionReview(), validationEnabled);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent) {
        this(fluent, true);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new AdmissionReview(), validationEnabled);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview instance) {
        this(fluent, instance, true);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withRequest(instance.getRequest()); 
        fluent.withResponse(instance.getResponse()); 
        this.validationEnabled = validationEnabled; 
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview instance) {
        this(instance,true);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withRequest(instance.getRequest()); 
        this.withResponse(instance.getResponse()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview build() {
        AdmissionReview buildable = new AdmissionReview(fluent.getApiVersion(),fluent.getKind(),fluent.getRequest(),fluent.getResponse());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        AdmissionReviewBuilder that = (AdmissionReviewBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-admissionregistration-5.4.2-sources.jar: io/fabric8/kubernetes/api/model/admission/v1beta1/AdmissionReviewBuilder.java <==
package io.fabric8.kubernetes.api.model.admission.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class AdmissionReviewBuilder extends io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluentImpl<io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewBuilder> {

    io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public AdmissionReviewBuilder() {
        this(true);
    }

    public AdmissionReviewBuilder(java.lang.Boolean validationEnabled) {
        this(new AdmissionReview(), validationEnabled);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent) {
        this(fluent, true);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new AdmissionReview(), validationEnabled);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview instance) {
        this(fluent, instance, true);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withRequest(instance.getRequest()); 
        fluent.withResponse(instance.getResponse()); 
        this.validationEnabled = validationEnabled; 
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview instance) {
        this(instance,true);
    }

    public AdmissionReviewBuilder(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withRequest(instance.getRequest()); 
        this.withResponse(instance.getResponse()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReview build() {
        AdmissionReview buildable = new AdmissionReview(fluent.getApiVersion(),fluent.getKind(),fluent.getRequest(),fluent.getResponse());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        AdmissionReviewBuilder that = (AdmissionReviewBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
